@@ -1,7 +1,7 @@
 package Complete::Riap;
 
-our $DATE = '2015-01-13'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-03-07'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -46,6 +46,12 @@ _
         },
         dig_leaf => {
             schema => 'bool',
+            description => <<'_',
+
+Unlike in Complete::Path, `dig_leaf` defaults to 0 because require modules
+recursively is slow and prone to compile errors.
+
+_
         },
         type => {
             schema => ['str*', in=>['function','package']], # XXX other types?
@@ -67,7 +73,7 @@ sub complete_riap_url {
     my $ci          = $args{ci} // $Complete::OPT_CI;
     my $map_case    = $args{map_case} // $Complete::OPT_MAP_CASE;
     my $exp_im_path = $args{exp_im_path} // $Complete::OPT_EXP_IM_PATH;
-    my $dig_leaf    = $args{dig_leaf} // $Complete::OPT_DIG_LEAF;
+    my $dig_leaf    = $args{dig_leaf} // 0; #$Complete::OPT_DIG_LEAF;
     my $type = $args{type} // '';
 
     my $starting_path;
@@ -133,7 +139,7 @@ Complete::Riap - Riap-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.04 of Complete::Riap (from Perl distribution Complete-Riap), released on 2015-01-13.
+This document describes version 0.05 of Complete::Riap (from Perl distribution Complete-Riap), released on 2015-03-07.
 
 =head1 SYNOPSIS
 
@@ -146,12 +152,10 @@ This document describes version 0.04 of Complete::Riap (from Perl distribution C
 
 =head2 complete_riap_url(%args) -> any
 
-{en_US Complete Riap URL}.
+Complete Riap URL.
 
-{en_US 
 Currently only support local Perl schemes (e.g. C</Pkg/Subpkg/function> or
 C<pl:/Pkg/Subpkg/>).
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -159,10 +163,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ci> => I<bool>
 
-{en_US Whether to do case-insensitive search}.
+Whether to do case-insensitive search.
 
 =item * B<dig_leaf> => I<bool>
 
+Unlike in Complete::Path, C<dig_leaf> defaults to 0 because require modules
+recursively is slow and prone to compile errors.
+
 =item * B<exp_im_path> => I<bool>
 
 =item * B<map_case> => I<bool>
@@ -171,7 +178,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<type> => I<str>
 
-{en_US Filter by entity type}.
+Filter by entity type.
 
 =item * B<word>* => I<str>
 
